augment_leaf

Function augment_leaf 

fn augment_leaf(tree: &mut [i32; 32], value: i32, to: usize)
Augment the correct leaf by the given non-negative value. Walks up the tree starting at the given index until finding a leaf node. Storing the tree as an implicit structure has a nice benefit that finding the next left or right node is straightforward.