fn split(tree: &mut [i32; 32])Expand description
Split a node into two child nodes.
Search the tree starting with the leaves, splitting the first node over 10 found (if any).
We can optimize the rules by immediately exploding if this happens in a node 4 levels deep.